Coverage report

# Coverage report: 73%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 557 | 149 | 9 | 73%
/home/kale/hacking/hobbies/two_cents/two_cents/__init__ | 2 | 0 | 0 | 100%
/home/kale/hacking/hobbies/two_cents/two_cents/banks | 80 | 60 | 0 | 25%
/home/kale/hacking/hobbies/two_cents/two_cents/cli | 204 | 55 | 0 | 73%
/home/kale/hacking/hobbies/two_cents/two_cents/model | 271 | 34 | 9 | 87%